#
# spec file for package PrusaSlicer
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           PrusaSlicer
Version:        2.4.2
Release:        bp156.2.47
Summary:        G-code generator for 3D printers (RepRap, Makerbot, Ultimaker etc.)
License:        AGPL-3.0-only
Group:          Hardware/Printing
URL:            https://www.prusa3d.com/prusaslicer/
Source0:        https://github.com/prusa3d/PrusaSlicer/archive/version_%{version}.tar.gz#/%{name}-%{version}.tar.gz
# PATCH-FIX-UPSTREAM PrusaSlicer-boost1.79.patch -- gh#prusa3d/PrusaSlicer#8238
Patch0:         PrusaSlicer-boost1.79.patch
# PATCH-FIX-UPSTREAM PrusaSlicer-cereal.patch -- gh#prusa3d/PrusaSlicer#7809
Patch1:         PrusaSlicer-cereal.patch
BuildRequires:  blosc-devel
BuildRequires:  cereal-devel
BuildRequires:  cgal-devel >= 4.13.2
BuildRequires:  cmake
BuildRequires:  eigen3-devel >= 3
BuildRequires:  expat
BuildRequires:  fdupes
# gcc v8 is required as least for charconv header. version 10 exists on 15.4 and tumbleweed
%if 0%{?suse_version} >= 1550
%define gcc_ver %{gcc_version}
%else
%define gcc_ver 10
%endif
BuildRequires:  gcc%gcc_ver-c++
# For now, use bundled GLEW because of gh#prusa3d/PrusaSlicer#6396
#!BuildIgnore:  glew-devel
#!BuildIgnore:  libglfw3-wayland
BuildRequires:  gtest >= 1.7
BuildRequires:  libboost_atomic-devel
BuildRequires:  libboost_filesystem-devel
BuildRequires:  libboost_iostreams-devel
BuildRequires:  libboost_locale-devel
BuildRequires:  libboost_log-devel
BuildRequires:  libboost_regex-devel
BuildRequires:  libboost_system-devel
BuildRequires:  libboost_thread-devel
BuildRequires:  libcurl-devel
BuildRequires:  libexpat-devel
BuildRequires:  memory-constraints
BuildRequires:  nlopt-devel
BuildRequires:  openexr-devel
BuildRequires:  openvdb-devel >= 5
BuildRequires:  openvdb-tools
BuildRequires:  pkgconfig
BuildRequires:  tbb-devel
BuildRequires:  update-desktop-files
# Quoting Lucas Matena (see gh#prusa3d/PrusaSlicer#8299, issue 2):
# if you link PrusaSlicer 2.5.x with wxWidgets 3.2, you will most likely break it.
BuildRequires:  wxWidgets-3_0-devel
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(libudev)
Requires:       noto-sans-fonts

%description
PrusaSlicer takes 3D models (STL, OBJ, AMF) and converts them into G-code
instructions for FFF printers or PNG layers for mSLA 3D printers. It's
compatible with any modern printer based on the RepRap toolchain, including
all those based on the Marlin, Prusa, Sprinter and Repetier firmware.
It also works with Mach3, LinuxCNC and Machinekit controllers.

%prep
%autosetup -p1 -n %{name}-version_%{version}
%if 0%{?suse_version}
sed -i 's/UNKNOWN/%{release}-%{?is_opensuse:open}SUSE-%{suse_version}/' version.inc
%endif
# this is not prusaslicer specific, space mouse users install it themselves
rm resources/udev/90-3dconnexion.rules

%build
# The build process really acquires that much memory per job. We are
# limited by memory not by CPU cores. Using memoryperjob in _constraints cannot
# provide any workers on some architectures. This is still better than not using
# parallel building at all.
# https://openbuildservice.org/help/manuals/obs-user-guide/cha.obs.build_job_constraints.html
# https://en.opensuse.org/openSUSE:Specfile_guidelines#Parallel_make
%limit_build -m 3072
# sse2 flags for 32-bit: see gh#prusa3d/PrusaSlicer#3781
%ifarch %ix86
  export CFLAGS="%optflags -mfpmath=sse -msse2"
  export CXXFLAGS="$CFLAGS"
%endif
export CC=gcc-%gcc_ver CXX=g++-%gcc_ver
# rh#2059646
sed -i tests/libslic3r/CMakeLists.txt -e '\@test_voronoi.cpp@d'

%cmake \
  -DSLIC3R_FHS=1 \
  -DSLIC3R_GTK=2 \
  -DSLIC3R_WX_STABLE=1 \
  -DOPENVDB_FIND_MODULE_PATH=%{_libdir}/cmake/OpenVDB
%cmake_build

%install
%cmake_install

%suse_update_desktop_file -r PrusaSlicer Graphics 3DGraphics Science Engineering
%suse_update_desktop_file -r PrusaGcodeviewer Graphics 3DGraphics

#remove stray font file
rm -rf %{buildroot}%{_datadir}/%{name}/fonts

# Copied and adapted from Fedora package:
# https://src.fedoraproject.org/rpms/prusa-slicer
# Upstream installs the translation source files when they probably shouldn't
rm %{buildroot}%{_datadir}/%{name}/localization/{PrusaSlicer.pot,list.txt}
find %{buildroot}%{_datadir}/%{name}/localization/ -name \*.po -delete

# Copied and adapted from Fedora package:
# https://src.fedoraproject.org/rpms/prusa-slicer
# Handle locale files.  The find_lang macro doesn't work because it doesn't
# understand the directory structure.  This copies part of the funtionality of
# find-lang.sh by:
#   * Getting a listing of all files
#   * removing the buildroot prefix
#   * inserting the proper 'lang' tag
#   * removing everything that doesn't have a lang tag
#   * A list of lang-specific directories is also added
# The resulting file is included in the files list, where we must be careful to
# exclude that directory.
find %{buildroot}%{_datadir}/%{name}/localization -type f -o -type l | sed '
    s:'"%{buildroot}"'::
    s:\(.*/%{name}/localization/\)\([^/_]\+\)\(.*\.mo$\):%%lang(\2) \1\2\3:
    s:^\([^%].*\)::
    s:%lang(C) ::
    /^$/d
' > lang-files
find %{buildroot}%{_datadir}/%{name}/localization -type d | sed '
    s:'"%{buildroot}"'::
    s:\(.*\):%dir \1:
' >> lang-files

%fdupes %{buildroot}%{_datadir}

%check
%ctest --timeout 600

%files -f lang-files
%{_bindir}/prusa-slicer
%{_bindir}/prusa-gcodeviewer
%dir %{_datadir}/%{name}/
%{_datadir}/%{name}/{icons,models,profiles,shaders,udev,data,shapes}/
%{_datadir}/icons/hicolor/32x32/apps/%{name}.png
%{_datadir}/icons/hicolor/128x128/apps/%{name}.png
%{_datadir}/icons/hicolor/192x192/apps/%{name}.png
%{_datadir}/icons/hicolor/32x32/apps/%{name}-gcodeviewer.png
%{_datadir}/icons/hicolor/128x128/apps/%{name}-gcodeviewer.png
%{_datadir}/icons/hicolor/192x192/apps/%{name}-gcodeviewer.png
%{_datadir}/applications/PrusaSlicer.desktop
%{_datadir}/applications/PrusaGcodeviewer.desktop
%license LICENSE
%doc README.md doc/

%changelog
* Mon Sep  5 2022 Hans-Peter Jansen <hpj@urpla.net>
- Quoting Lucas Matena (see gh#prusa3d/PrusaSlicer#8299, issue 2):
  if you link PrusaSlicer 2.5.x with wxWidgets 3.2, you will most
  likely break it: link against wxWidgets 3.0.5
* Mon Aug  1 2022 Ben Greiner <code@bnavigator.de>
- Add PrusaSlicer-cereal.patch -- gh#prusa3d/PrusaSlicer#7809
* Tue May 31 2022 Ben Greiner <code@bnavigator.de>
- Disable test_voronoi -- rh#2059646
* Sun May  8 2022 Ben Greiner <code@bnavigator.de>
- Update to version 2.4.2
  * SLA mode incorrectly handled 3MFs from 3rd party software,
    resulting in misplaced SLA support points and holes in some
    cases (#6100, #7359, #7189, #7826, #7659). This is very old
    issue.
  * Vase mode preview did not show in cases when Custom Start
    G-Code lacked moves in Z #8032
  * When loading a 3rd party 3MF using drag and drop. PrusaSlicer
    no longer asks if the 3MF shall be loaded as a project (which
    makes no sense since it contains no config) and loads the
    geometry only
  * Using the Layer Height Modifier with the wipe tower was
    impossible with multiple objects. The wipe tower reported that
    the layer height profile is different, even though it was in
    fact set the same on all objects (#7711, #7903, #8044)
  * Fixed a crash on "Convert from/to units" when several objects
    were selected
  * Automatic color change for logo crashed PrusaSlicer in certain
    cases (when a one-layer object was present) #8156
  * Linux specific: Fixed a crash on opening projects in some cases
    (#8078, #8097)
  * Added Snapmaker bundle (Snapmaker A250, Snapmaker A350). Based
    on https://github.com/nivekmai/snapmaker-prusa by @nivekmai,
    @WilliamBosacker, @mrworf
  * Added profiles for Zonestar printers (Z5, Z6, Z5X, Z8, Z9),
    based on slic3r/slic3r-profiles#19 by @ZONESTAR3D
  * Fixed a crash when Unsaved Changes dialog attempted to show a
    modified config option which is not available in current mode
    (e.g. Start G-Code in Simple mode). #7905
  * Fixed a bug that when the user was closing the application and
    replied 'Yes' in the dialog asking about unsaved project while
    also checking 'Remember my choice', it made it impossible to
    close PrusaSlicer in the next runs when there were no objects
    in the plater #8076, #8122
  * Loading of a G-Code in G-Code Viewer or loading config from
    G-Code file sometimes failed because of a bug in parsing of the
    configuration block at the end.
  * Fixed incorrect rendering of some characters used in the
    recently updated Simplified Chinese translation #8171
  * Fixed incorrect number of toolchanges reported in "Sliced Info"
    box when wipe tower was used. The annotations of toolchanges in
    G-Code were also numbered wrong #8186
  * Fixed a crash when using the "Import SL1 Archive" function and
    either cancelling the dialog or confirming a non-existing file
    [#8175]
  * Recycling symbols in Shape Gallery were mirrored so the user
    does not have to flip them when using them as negative volumes
    at the base of the print (which is the usual use case). Also,
    PLA recycling symbol was added #7800
* Mon Apr 25 2022 Ben Greiner <code@bnavigator.de>
- Refresh PrusaSlicer-boost1.79.patch with upstream's fix
  * gh#prusa3d/PrusaSlicer#8238
* Sun Apr 24 2022 Ben Greiner <code@bnavigator.de>
- Add PrusaSlicer-boost1.79.patch avoiding the deprecation
  of boost::filesystem::ofstream in Boost 1.79
  * gh#prusa3d/PrusaSlicer#8238
* Tue Apr 12 2022 Hans-Peter Jansen <hpj@urpla.net>
- Use gcc version 10 for anything but Tumbleweed
* Tue Apr 12 2022 Adrian Schröter <adrian@suse.de>
- Use gcc version 10
  This allows the build on Leap 15.3/15.4 and in Factory using the same
  compiler.
- Add buildignore to libglfw3-wayland to fix building for 15.3
* Fri Mar 18 2022 Ben Greiner <code@bnavigator.de>
- Update to 2.4.1
  * Big changelog since v2.4.0, most changes decribed in alpha and
    beta release notes:
    https://github.com/prusa3d/PrusaSlicer/releases
  * introducing G-Code Substitutions
  * fixing bugs found in 2.4.0 release
* Fri Dec 24 2021 Ben Greiner <code@bnavigator.de>
- Update to 2.4.0
  * Big changelog since v2.3.3, most changes decribed in alpha and
    beta release notes:
    https://github.com/prusa3d/PrusaSlicer/releases
  * Send system info: new dialog for telemetry. Opt-in.
- Drop patches
  * PrusaSlicer-catch2upd.patch
  * PrusaSlicer-issue6681-openvdb.patch
  * PrusaSlicer-pr6590-updateTBB.patch
* Tue Nov 23 2021 Ben Greiner <code@bnavigator.de>
- Make compatible with TBB 2021
  * add FindTBB.cmake -- gh#prusa3d/PrusaSlicer#7332
  * add PrusaSlicer-pr6590-updateTBB.patch
    gh#prusa3d/PrusaSlicer#6590
* Fri Sep 24 2021 Ben Greiner <code@bnavigator.de>
- Add PrusaSlicer-catch2upd.patch
  * gh#prusa3d/PrusaSlicer#6518
  * Update of Catch2 test framework from v2.13.3 to v2.13.6
  * Fixes build failure due to change of MINSIGSTKSZ in glibc 2.34
* Mon Aug 30 2021 Ben Greiner <code@bnavigator.de>
- Add PrusaSlicer-issue6681-openvdb.patch
  * gh#prusa3d/PrusaSlicer#6681
  * ilmbase-devel is now provided by openexr-devel
  * OpenVDB's FindOpenVDB.cmake requires blosc-devel
* Fri Jul 16 2021 Ben Greiner <code@bnavigator.de>
- Update to v2.3.3
  * fix a bug in handling FDM multi-material project and
    configuration files.
* Fri Jul  9 2021 Ben Greiner <code@bnavigator.de>
- Update to v2.3.2
  * Introducing support for the new Prusa SL1S SPEED masked
    SLA printer, Prusa CW1S firmware updater, PrusaLink
    host type for Prusa i3 MK3 printers, Monotonic infill
    for all solid layers, better support for reading
    configurations of newer PrusaSlicer releases, new 3rd
    party printer profiles and a handful of bug fixes.
- Switch to bundled GLEW -- gh#prusa3d/PrusaSlicer#6396
* Tue Apr 20 2021 Ben Greiner <code@bnavigator.de>
- Update to v2.3.1
  New 3rd party printer profiles
  * Multiple Creality printers profiles were added (Ender-3 Max,
    Ender-4, Ender-6, CR-5 Pro, CR-5 Pro H, CR-6 SE, CR-6 Max,
    CR-10 Max, CR-200B, CR-8), thanks @pmjdebruijn.
  * Added Artillery printer profiles (Sidewinder X1, Genius),
    thanks @SzabolcsHornyak.
  * Added INAT printer profiles, thanks @MarkINAT.
  * Updated Anycubic Kossel bed texture (thanks @brunosso) and
    Anycubic Kossel bed STL.
  Vulnerability issues fixed
  * The Talos Cisco Intelligence Group did a great job identifying
    potential security issues in loading invalid and potentially
    malicious AMF and 3MF files, see their vulnerability reports
    TALOS-2020-1222 and TALOS-2020-1218. We fixed these two
    potential security issues with this release of PrusaSlicer.
  Bugs fixed with respect to PrusaSlicer 2.3.0
  * Reduced number of hits shown by the "Find config option"
    dialog, fixed case insensitive search for non-Latin1 languages
    [#5202].
  * Fixed G-code preview with coloring by a tool and visualization
    of travels enabled #6095.
  * Fixed opening of drop down menus at the bottom of the screen
    on multi-monitor setups #2999 #5911 #5957. This issue has been
    fixed by us in wxWidgets and accepted by the upstream.
* Mon Jan 11 2021 Benjamin Greiner <code@bnavigator.de>
- Update to v2.3.0
  * Introducing paint-on supports, ironing, monotonic
    infill, seam painting, adaptive and support cubic
    infill, print time per feature analysis, standalone
    G-code viewer application, better auto-arrange with a
    customizable gap and rotation, search function for the
    settings, reworked "Avoid crossing perimeters" function,
    physical printers (network settings), many new 3rd party
    printer profiles and much, much more.
- Full Changelog entries for betas and release candidates:
  https://github.com/prusa3d/PrusaSlicer/releases
- Drop PrusaSlicer-pr4340-boost-1-73.patch merged upstream
* Sun Dec 20 2020 Benjamin Greiner <code@bnavigator.de>
- Remove extra PrusaSlicer.desktop. Use upstream's desktop files.
  Graphics;3DGraphics seems to be the consensus now.
- Remove wrapper gh#prusa3d/PrusaSlicer#4691
* Tue Sep  1 2020 Benjamin Greiner <code@bnavigator.de>
- support boost >= 1.73
  * PrusaSlicer-pr4340-boost-1-73.patch gh#prusa3d/PrusaSlicer#4340
  * fixes gh#prusa3d/PrusaSlicer#4264
* Tue Sep  1 2020 Benjamin Greiner <code@bnavigator.de>
- enforce GDK_BACKEND=x11 by indroducing the same wrapper as Fedora
  gh#prusa3d/PrusaSlicer#4691
* Thu Aug 20 2020 Benjamin Greiner <code@bnavigator.de>
- revert the memoryperjob change. The build process really acquires
  that much memory per job and the workers cannot provide 3GB per
  CPU core. Sadly, we are limited by memory not by CPU cores.
- require 11 GB of RAM. This allows us to run 3 jobs in parallel and
  can be provided by all architectures
* Thu Aug 20 2020 Martin Liška <mliska@suse.cz>
- Use memoryperjob constraint instead of %%limit_build macro.
- Use only 1GB for memoryperjob.
* Mon Aug 10 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Use wxGTK3 instead of wxWidgets (GTK2), for better HiDPI and
  Wayland support.
* Tue Jun 16 2020 Benjamin Greiner <code@bnavigator.de>
- This is mainly a cosmetic update so that the package gets rebuilt
  in Factory. Rebuild is needed because of wxWidgets - boo#1172750
- Add openvdb-tools package for better cmake reporting.
- Make the 32-bit floating point workaround more readable.
  gh#prusa3d/PrusaSlicer#3781
* Fri Apr 24 2020 Dominique Leuenberger <dimstar@opensuse.org>
- BuildRequire pkgconfig(libudev) instead of libudev-devel: allow
  OBS to shortcut through -mini flavors.
* Sat Mar 21 2020 Benjamin Greiner <code@bnavigator.de>
- update to version 2.2.0
  introducing SLA hollowing and hole drilling, support for 3rd party
  printer vendors, 3Dconnexion support, automatic variable layer height,
  macOS dark mode support, greatly improved ColorPrint feature and much,
  much more.
  See https://github.com/prusa3d/PrusaSlicer/releases/tag/version_2.2.0
  and the changelogs for the release candidates, betas and alphas since
  2.1.1 for a complete list of changes.
- reactivate parallel builds, but need strong enough workers and reserve
  4G of memory per thread (memory-constraints, %%limit_build)
- new build dependencies: cgal, ilmbase, more of boost, libudev, openvdb
* Wed Dec 11 2019 Benjamin Greiner <code@bnavigator.de>
- update to version 2.1.1
  - integrating the Prusa Mini printer into the
    installation wizard
  - 3D scene thumbnails are newly generated and exported
    into the G-code to be displayed on the Prusa Mini
    printer's display
- use Graphics;3DGraphics for non Tumbleweed distros
* Fri Sep 13 2019 Benjamin Greiner <code@bnavigator.de>
- final 2.1.0
- symlink icon files instead of duplicate copy
* Sat Sep  7 2019 Benjamin Greiner <code@bnavigator.de>
- new version 2.1.0-rc
- remove obsolete patch file
- tag localization files
- remove stray Noto font file, add as dependency
- outsource Desktop file creation
- move Desktop category to "Science;Construction"
* Mon Jul 29 2019 Benjamin Greiner <code@bnavigator.de>
- Clean up specfile according to declined submit request 718985
  - Remove non-devel BuildRequires
  - Move icons to icons/hicolor
- build with -j1 as otherwise x64 build is stuck
* Fri Jul 26 2019 Benjamin Greiner <code@bnavigator.de>
- use new patch from upstream
  (see https://github.com/prusa3d/PrusaSlicer/pull/2676)
- use Education;Construction as long as boo#1074711 is not resolved
* Tue Jul 23 2019 Benjamin Greiner <code@bnavigator.de>
- initial specfile
